==> core-1.70.0-sources.jar: software/amazon/awscdk/core/Aspects.java <==
package software.amazon.awscdk.core;

/**
 * Aspects can be applied to CDK tree scopes and can operate on the tree before synthesis.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.13.0 (build 385c325)", date = "2020-10-23T23:56:37.130Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Aspects")
public class Aspects extends software.amazon.jsii.JsiiObject {

    protected Aspects(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Aspects(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Returns the `Aspects` object associated with a construct scope.
     * <p>
     * @param scope The scope for which these aspects will apply. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Aspects of(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.IConstruct scope) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Aspects.class, "of", software.amazon.awscdk.core.Aspects.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }

    /**
     * Adds an aspect to apply this scope before synthesis.
     * <p>
     * @param aspect The aspect to add. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void add(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.IAspect aspect) {
        this.jsiiCall("add", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(aspect, "aspect is required") });
    }

    /**
     * The list of aspects which were directly applied on this scope.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.core.IAspect> getAspects() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("aspects", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.IAspect.class))));
    }
}

==> core-1.71.0-sources.jar: software/amazon/awscdk/core/Aspects.java <==
package software.amazon.awscdk.core;

/**
 * Aspects can be applied to CDK tree scopes and can operate on the tree before synthesis.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.14.0 (build 729554b)", date = "2020-10-29T17:33:53.204Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Aspects")
public class Aspects extends software.amazon.jsii.JsiiObject {

    protected Aspects(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Aspects(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Returns the `Aspects` object associated with a construct scope.
     * <p>
     * @param scope The scope for which these aspects will apply. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Aspects of(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.IConstruct scope) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Aspects.class, "of", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Aspects.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }

    /**
     * Adds an aspect to apply this scope before synthesis.
     * <p>
     * @param aspect The aspect to add. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void add(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.IAspect aspect) {
        software.amazon.jsii.Kernel.call(this, "add", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(aspect, "aspect is required") });
    }

    /**
     * The list of aspects which were directly applied on this scope.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.core.IAspect> getAspects() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "aspects", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.IAspect.class))));
    }
}
